import { HTMLAttributes } from 'react';
import { Range } from './histogram';
import '../styles/components/histogram-filter.scss';
type Props = {
    /**
     * The left-most, smallest, value the histogram starts at irrespective of the
     * array values. Defaults to min(values).
     */
    min?: number;
    /**
     * The right-most, largest, value the histogram ends at irrespective of the
     * array values. Defaults to max(values).
     */
    max?: number;
    /**
     * An array of values which the histogram is based on.
     */
    values: number[];
    /**
     * An array of unfiltered values which the histogram is based on.
     * (useful to calculate max bin height)
     */
    unfilteredValues?: number[];
    /**
     * A value which specifies the start and end points selected by the user.
     */
    selectedRange: Range;
    /**
     * A callback that returns the selected and final (ie after drag) range.
     */
    onChange: (range: Range) => unknown;
    /**
     * Number of bins (intervals) which the values are allocated to.
     * Each interval is of the size (max - min) / nBins. Defaults to 50.
     */
    nBins?: number;
    /**
     * The height in pixels of the bin with the most values. Defaults to 300.
     */
    height?: number;
    /**
     * Display a shadow of the unfiltered data (opacity value)
     */
    unfilteredValuesShadow?: number;
    /**
     * Additional CSS classnames to apply (eg secondary, tertiary)
     */
    className?: string;
};
declare const HistogramFilter: ({ min: minOrUndef, max: maxOrUndef, values, unfilteredValues, unfilteredValuesShadow, selectedRange, onChange, nBins, height, className, ...props }: Props & Omit<HTMLAttributes<HTMLDivElement>, "onChange">) => import("react/jsx-runtime").JSX.Element;
export default HistogramFilter;
