import { FC, HTMLAttributes, PropsWithChildren, ReactElement, ReactNode } from 'react';
import { HeadingLevels } from '../types/common';
import '../styles/components/tile.scss';
type Props = {
    /**
     * The tile title
     */
    title: ReactNode;
    /**
     * The tile title heading level
     */
    headingLevel?: Exclude<HeadingLevels, 'h6'>;
    /**
     * The tile subtitle
     */
    subtitle?: ReactNode;
    /**
     * The background color
     */
    backgroundColor?: string;
    /**
     * The background image
     */
    backgroundImage?: ReactNode;
    /**
     * Whether to create a gradient based on the backgroung color or not
     */
    gradient?: boolean;
    /**
     * The width Tile square (css value). By default it will use the
     * width of the provided container.
     */
    width?: string;
    /**
     * Whether to slide up the description when the mouse is over the tile.
     * Can be useful if the description text is long.
     */
    descriptionSlideUp?: boolean;
    /**
     * Target/link of the list item when clicking on it
     */
    link?: ReactElement;
};
export declare const Tile: FC<PropsWithChildren<Props> & HTMLAttributes<HTMLDivElement>>;
export default Tile;
