export declare const validAminoAcids: string;
export declare const validNucleicAcids: string;
export declare const errorResponses: Readonly<{
    missingSequence: Readonly<{
        valid: false;
        message: "The sequence is missing";
    }>;
    invalidSequence: Readonly<{
        valid: false;
        message: "The sequence is invalid";
    }>;
    shortSequence: Readonly<{
        valid: false;
        message: "The sequence is too short";
    }>;
}>;
export declare const validResponse: Readonly<{
    valid: true;
}>;
export declare function findLikelyType(sequence: string): "aa" | "na";
/**
 * Core internal validation function for a single sequence
 *
 * @param {string} sequence - A sequence
 * @return {object} The result
 */
export declare function sequenceValidator(sequence: string, minimumLength?: number, strict?: boolean): Readonly<{
    valid: false;
    message: "The sequence is missing";
}> | Readonly<{
    valid: false;
    message: "The sequence is invalid";
}> | Readonly<{
    valid: false;
    message: "The sequence is too short";
}> | {
    likelyType: "aa" | "na";
    sequence: string;
    valid: true;
};
/**
 * Main validation function
 *
 * @param {Array<string>|string} sequences - An array of sequences or a string
 * @return {Array<object|null>} The result of validating each sequence
 * while keeping order intact.
 */
declare function validateSequences(input: string | string[], minimumLength?: number): (Readonly<{
    valid: false;
    message: "The sequence is missing";
}> | Readonly<{
    valid: false;
    message: "The sequence is invalid";
}> | Readonly<{
    valid: false;
    message: "The sequence is too short";
}> | {
    likelyType: "aa" | "na";
    sequence: string;
    valid: true;
})[];
export default validateSequences;
